sqlobject.tests.test_decimal module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_decimal module

class `sqlobject.tests.test_decimal.` `DecimalTable`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col1`
  property `col2`
  property `col3`
  `j` = decimal_table
  property `name`
  `q` = decimal_table
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_decimal.DecimalTable`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'decimal_table'

`sqlobject.tests.test_decimal.` `test_1_decimal`()

`sqlobject.tests.test_decimal.` `test_2_decimal`()